#!/bin/bash

# Install ClamAV with SELinux support

# If we haven't read functions.sh by now, then read it
if [ "x$ZTFUNCTIONS" = "x" ]; then
  if [ -f lib/functions.sh ]; then
    . lib/functions.sh
  elif [ -f ../lib/functions.sh ]; then
    cd ..
    . lib/functions.sh
  else
    echo 'Sorry, I need to be able to source functions.sh first.'
    echo Exiting...
    exit 1
  fi
fi

shout
shout =================================================================
shout
shout 'Install and configure ClamAV'
shout
shout =================================================================
shout
pause

# Install the RPMs we need
shout Installing ClamAV
zypper --non-interactive install clamav

# So apache can run clamdscan
usermod -a -G vscan wwwrun
# So clamd and clamdscan can read files created by apache
usermod -a -G www vscan
pause

shout Allowing ClamAV through AppArmor to read ZendTo uploads
if [ -d /etc/apparmor.d ]; then
  mkdir -p /etc/apparmor.d/local # Just in case
  APP=/etc/apparmor.d/local/usr.sbin.clamd
  # Create it if necessary
  if [ ! -f $APP ]; then
    :> $APP
    chown root:root $APP
    chmod 0644 $APP
  fi
  if fgrep -q zendto $APP; then
    shout No need, already done.
  else
    echo '# ZendTo settings (do not delete this line)' >> $APP
    echo '/var/zendto/** r,' >> $APP
  fi
  if systemctl is-enabled apparmor >/dev/null 2>&1; then
    shout Restarting apparmor as it was enabled.
    systemctl enable apparmor
    systemctl restart apparmor
  else
    shout As you are not using apparmor, I have not enabled it.
  fi

else
  shout "You do not appear to have AppArmor installed."
fi

shout
shout Fetch initial ClamAV signature databases
shout '(Ignore the error about not notifying clamd)'
freshclam

#shout Fixing ClamAV configuration files
## Edit freshclam.conf
## Set AllowSupplementaryGroups yes
#shout 'Allowing all the supplementary group memberships'
#if grep -Pq '^AllowSupplementaryGroups\s' /etc/freshclam.conf; then
#  perl -pi.zendto -e 's/^#?(AllowSupplementaryGroups).*$/AllowSupplementaryGroups yes/i;' /etc/freshclam.conf
#else
#  echo >> /etc/freshclam.conf
#  echo '# ZendTo allow all the groups we need' >> /etc/freshclam.conf
#  echo 'AllowSupplementaryGroups yes' >> /etc/freshclam.conf
#fi

# Enable and start both services
shout 'Enabling and starting clamd and freshclam services'
systemctl enable clamd
systemctl enable freshclam
systemctl start clamd
systemctl start freshclam

shout
shout ClamAV has been setup for you to work with ZendTo.
shout

exit 0

